"""Two input fields for position, uv, etc."""

# Import third-party modules
try:
    from PySide import QtCore
    from PySide import QtGui
    from PySide import QtGui as QtWidgets
except ImportError as error:
    from PySide2 import QtCore
    from PySide2 import QtGui
    from PySide2 import QtWidgets

# Import local modules
from smartEdit.widgets.base import KnobBase


class Array2d(KnobBase):
    """Two input fields for position, uv, etc.."""

    def create_widgets(self):
        """Create widgets."""
        self.label = QtWidgets.QLabel(self.knob.name())
        self.input_a = QtWidgets.QLineEdit()
        self.input_b = QtWidgets.QLineEdit()

    def setup_widgets(self):
        """Setup widgets."""
        self.input_a.setText(str(self.knob.value()[0]))
        self.input_b.setText(str(self.knob.value()[1]))

    def create_layouts(self):
        """Create layouts."""
        self.layout_main.addWidget(self.label)
        self.layout_main.addWidget(self.input_a)
        self.layout_main.addWidget(self.input_b)

    def create_signals(self):
        """Create signals."""
        self.input_a.returnPressed.connect(lambda: self.update())
        self.input_b.returnPressed.connect(lambda: self.update())

    def update(self):
        """Update the knob a to the current custom knob's values."""
        try:
            value_a = float(self.input_a.text())
            value_b = float(self.input_b.text())
        except (TypeError, ValueError):
            return

        self.knob.setValue([value_a, value_b])
