"""Three input fields for 3d position."""

# Import third-party modules
try:
    from PySide import QtCore
    from PySide import QtGui
    from PySide import QtGui as QtWidgets
except ImportError as error:
    from PySide2 import QtCore
    from PySide2 import QtGui
    from PySide2 import QtWidgets

# Import local modules
from smartEdit.widgets.array2d import Array2d


class Array3d(Array2d):
    """Three input fields for 3d position."""

    def create_widgets(self):
        """Create widgets."""
        super(Array3d, self).create_widgets()

        self.input_c = QtWidgets.QLineEdit()

        self.setup_widgets()

    def setup_widgets(self):
        """Setup widgets."""
        super(Array3d, self).setup_widgets()

        self.input_c.setText(str(self.knob.value()[2]))

    def create_layouts(self):
        """Create layouts."""
        super(Array3d, self).create_layouts()

        self.layout_main.addWidget(self.input_c)

    def create_signals(self):
        """Create signals."""
        super(Array3d, self).create_signals()

        self.input_c.returnPressed.connect(lambda: self.update())

    def update(self):
        """Update the knob a to the current custom knob's values."""
        try:
            value_a = float(self.input_a.text())
            value_b = float(self.input_b.text())
            value_c = float(self.input_c.text())
        except (TypeError, ValueError):
            return

        self.knob.setValue([value_a, value_b, value_c])
