"""String input to enter a strings of multiple lines."""

# Import third-party modules
try:
    from PySide import QtCore
    from PySide import QtGui
    from PySide import QtGui as QtWidgets
except ImportError as error:
    from PySide2 import QtCore
    from PySide2 import QtGui
    from PySide2 import QtWidgets

# Import local modules
from smartEdit.widgets.base import KnobBase


class Multilineinput(KnobBase):
    """String input to enter a strings of multiple lines."""

    def create_widgets(self):
        """Create widgets."""
        self.label = QtWidgets.QLabel(self.knob.name())
        self.input = QtWidgets.QTextEdit()

    def setup_widgets(self):
        """Setup widgets."""
        self.input.setText(self.knob.value())

    def create_layouts(self):
        """Create layouts."""
        self.layout_main.addWidget(self.label)
        self.layout_main.addWidget(self.input)

    def create_signals(self):
        """Create signals."""
        self.input.textChanged.connect(lambda: self.update())

    def update(self):
        """Update the node's dropdown to the currently selected value."""
        self.knob.setValue(self.input.toPlainText())
