"""Helper functions for this package."""


# Import built-in modules
import json
import os

# Import local modules
from smartEdit.constants import SMART_EDIT


def get_package_dir(private=True):
    """Get absolute path of package directory for this package.

    Create it if not already existing.

    Args:
        private (bool): If True get the private package directory, otherwise
            get the public one.

    Returns:
        str: Absolute path of package directory.

    """
    cragl_dir = ".cragl" if private else "cragl"

    path = os.path.join(os.path.expanduser("~"), cragl_dir, SMART_EDIT)

    if not os.path.isdir(path):
        os.makedirs(path)

    return path

def load_settings():
    """Load settings file without the need of a model.

    Returns:
        dict: The parsed settings file.

    """
    settings_file = os.path.join(get_package_dir(), "settings.json")
    with open(settings_file, "r") as file_:
        return json.load(file_)
