"""Custom dialog- and window classes."""

# PySide import switch
try:
    from PySide import QtGui as QtWidgets
    from PySide import QtCore
except ImportError as error:
    from PySide2 import QtWidgets
    from PySide2 import QtCore

# Import local modules
from smartEdit.mvc import gui_helper


class AddKnobDialog(QtWidgets.QDialog):
    """Window to add a knob for the given node or node class."""

    key_pressed = QtCore.Signal(str)

    def __init__(self):
        """Initialize the AddKnob instance."""
        super(AddKnobDialog, self).__init__()

        self.build_ui()

    def build_ui(self):
        """Build ui."""
        self.setWindowFlags(QtCore.Qt.WindowStaysOnTopHint)
        self.setModal(True)

        self.create_widgets()
        self.create_layouts()

    def create_widgets(self):
        """Create widgets."""
        self.combo = QtWidgets.QComboBox()
        self.check_apply_to_class = QtWidgets.QCheckBox("Add for node class")
        self.button_add = QtWidgets.QPushButton("Add")
        self.button_add.setProperty("style", "action_button")
        self.button_cancel = QtWidgets.QPushButton("Cancel")

    def create_layouts(self):
        """Create layouts."""
        self.layout_main = QtWidgets.QVBoxLayout()
        self.layout_top = QtWidgets.QHBoxLayout()
        self.layout_button = QtWidgets.QHBoxLayout()

        self.layout_top.addWidget(self.combo)
        self.layout_top.addWidget(self.check_apply_to_class)

        self.layout_button.addWidget(self.button_add)
        self.layout_button.addWidget(self.button_cancel)

        self.layout_main.addLayout(self.layout_top)
        self.layout_main.addLayout(self.layout_button)

        self.setLayout(self.layout_main)
        gui_helper.set_style_sheet(self)
    
    def keyPressEvent(self, event, *args):
        """Catch keyPressEvent to execute custom events."""
        super(AddKnobDialog, self).keyPressEvent(event)

        if event.key() == QtCore.Qt.Key_Return:
            self.key_pressed.emit("accept")

        if event.key() == QtCore.Qt.Key_Escape:
            self.key_pressed.emit("reject")


def show_message_box(window, message):
    """Show message box with message as content.

    Args:
        window (QtWidgets.QWidget): Parent window in order to keep the message
            box on top of the parent window.
        message (str): Message to display in the window.

    """
    dialog = QtWidgets.QMessageBox()
    dialog.setWindowFlags(QtCore.Qt.WindowStaysOnTopHint)
    dialog.information(window, 'information', message)
