"""Settings widget to customize smartEdit."""

# PySide import switch
try:
    from PySide import QtGui as QtWidgets
    from PySide import QtGui
    from PySide import QtCore
except ImportError as error:
    from PySide2 import QtWidgets
    from PySide2 import QtGui
    from PySide2 import QtCore

# Import local modules
from smartEdit.mvc import gui_helper


class Settings(QtWidgets.QWidget):
    """Settings widget to customize smartEdit."""

    def __init__(self):
        """Initialize the settings widget."""
        super(Settings, self).__init__()

        self.build_ui()

    def build_ui(self):
        """Build ui."""
        self.create_widgets()
        self.create_layouts()

    def create_widgets(self):
        """Create widgets."""
        self.check_show_tooltips = QtWidgets.QCheckBox("show tooltips")
        self.check_pin = QtWidgets.QCheckBox("pin")
        self.check_frameless = QtWidgets.QCheckBox("frameless")
        self.check_advanced_widgets = QtWidgets.QCheckBox("advanced widgets")
        self.check_enable_add_for_node_class = QtWidgets.QCheckBox(
            "Enable 'add for node class'")
        self.label_slider_precision = QtWidgets.QLabel("slider precision")
        self.label_hotkey = QtWidgets.QLabel("Hotkey to launch smartEdit")
        self.input_hotkey = QtWidgets.QLineEdit()
        self.input_hotkey.setProperty("style", "short")
        self.spin_slider_precision = QtWidgets.QSpinBox()
        self.spin_slider_precision.setMinimum(2)
        self.spin_slider_precision.setMaximum(7)

        self.label_slider = QtWidgets.QLabel("window opacity")
        self.slider = QtWidgets.QSlider()
        self.slider.setOrientation(QtCore.Qt.Horizontal)
        self.slider.setMinimum(29)
        self.slider.setMaximum(101)

        self.input_slider_percentage = QtWidgets.QLineEdit()

        self.text_ignore = QtWidgets.QTextEdit()
        self.text_ignore.setProperty("style", "no-border")

        self.button_save = QtWidgets.QPushButton("save")
        self.button_save.setProperty("style", "action_button")

    def create_layouts(self):
        """Create layouts."""
        self.layout_main = QtWidgets.QVBoxLayout()
        self.layout_knobs_ignore = QtWidgets.QVBoxLayout()
        self.layout_slider_precision = QtWidgets.QHBoxLayout()
        self.layout_slider = QtWidgets.QHBoxLayout()

        self.layout_slider.addWidget(self.label_slider, 1)
        self.layout_slider.addWidget(self.slider, 8)
        self.layout_slider.addWidget(self.input_slider_percentage, 1)

        self.layout_slider_precision.addWidget(self.label_slider_precision)
        self.layout_slider_precision.addWidget(self.spin_slider_precision)
        self.layout_slider_precision.addStretch()

        self.layout_hotkey = QtWidgets.QHBoxLayout()
        self.layout_hotkey.addWidget(self.label_hotkey)
        self.layout_hotkey.addWidget(self.input_hotkey)
        self.layout_hotkey.addStretch()

        self.group_knobs_ignore = QtWidgets.QGroupBox("ignore knobs")
        self.group_knobs_ignore.setLayout(self.layout_knobs_ignore)
        self.layout_knobs_ignore.addWidget(self.text_ignore)

        self.layout_main.addWidget(self.check_show_tooltips)
        self.layout_main.addWidget(self.check_pin)
        self.layout_main.addWidget(self.check_frameless)
        self.layout_main.addWidget(self.check_advanced_widgets)
        self.layout_main.addWidget(self.check_enable_add_for_node_class)
        self.layout_main.addLayout(self.layout_hotkey)
        self.layout_main.addLayout(self.layout_slider_precision)
        self.layout_main.addLayout(self.layout_slider)
        self.layout_main.addWidget(self.group_knobs_ignore)
        self.layout_main.addWidget(self.button_save)

        self.setLayout(self.layout_main)
        gui_helper.set_style_sheet(self)
