"""Button to execute a callable."""

# Import third-party modules
try:
    from PySide import QtCore
    from PySide import QtGui
    from PySide import QtGui as QtWidgets
except ImportError as error:
    from PySide2 import QtCore
    from PySide2 import QtGui
    from PySide2 import QtWidgets

# Import local modules
from smartEdit.widgets.base import KnobBase


class Button(KnobBase):
    """Button to execute a callable."""

    def create_widgets(self):
        """Create widgets."""
        self.button = QtWidgets.QPushButton(self.knob.name())

    def create_layouts(self):
        """Create layouts."""
        self.layout_main.addWidget(self.button)

    def create_signals(self):
        """Create signals."""
        self.button.clicked.connect(lambda: self.execute())

    def execute(self):
        """Execute the knob's button."""
        self.knob.execute()
